.. image:: https://acesseonline-arquivos-publicos.s3.us-east-2.amazonaws.com/logo-pyreportjasper.png
   :scale: 50 %
   :alt: PyReportJasper logo
   :align: center

PyReportJasper
==============

|pyversions|  |javaversions|  |jvm|  |platform|  |license|

This package aims to be a solution to compile and process JasperReports
(.jrxml & .jasper files).

Did you ever had to create a good looking Invoice with a lot of fields
for your great web app or desktop?

I had to, and the solutions out there were not perfect. Generating
*HTML* + *CSS* to make a *PDF*? WTF? That doesn't make any sense! :)

Then I found **JasperReports** the best open source solution for
reporting.

**From their website:**

    The JasperReports Library is the world's most popular open source
    reporting engine. It is entirely written in Java and it is able to
    use data coming from any kind of data source and produce
    pixel-perfect documents that can be viewed, printed or exported in a
    variety of document formats including HTML, PDF, Excel, OpenOffice
    and Word.


:Code: `GitHub
 <https://github.com/acesseonline/pyreportjasper>`_
:Issue tracker: `GitHub Issues
 <https://github.com/acesseonline/pyreportjasper/issues>`_
:Documentation: `Python Docs`_
:License: `GNU GENERAL PUBLIC LICENSE`_
:Build status:  |TestsCI|_
:Version: |PypiVersion|_ |Conda|_


.. |PypiVersion| image:: https://img.shields.io/pypi/v/pyreportjasper?style=flat-square
.. _PypiVersion: https://pypi.org/project/pyreportjasper/
.. |Conda| image:: https://anaconda.org/acesseonline/pyreportjasper/badges/version.svg
.. _Conda: https://anaconda.org/acesseonline/pyreportjasper

.. |TestsCI| image:: https://github.com/acesseonline/pyreportjasper/workflows/Tests/badge.svg?branch=master
.. _TestsCI: https://github.com/acesseonline/pyreportjasper/actions?query=workflow%3ATests
.. |pyversions| image:: https://img.shields.io/badge/python-3.5%20or%20higher-blue.svg
.. |javaversions| image:: https://img.shields.io/badge/java-9%20or%20higher-purple.svg
.. |jvm| image:: https://img.shields.io/badge/jvm-Open%20%7C%20Oracle%20%7C%20Corretto-purple.svg
.. |platform| image:: https://img.shields.io/badge/platform-linux%20%7C%20windows%20%7C%20mac-lightgrey
.. _GNU GENERAL PUBLIC LICENSE: https://github.com/acesseonline/pyreportjasper/blob/master/LICENSE
.. _Python Docs: https://pyreportjasper.readthedocs.io/en/latest/
.. |license| image:: https://img.shields.io/badge/License-GPLv3-blue.svg
   :target: https://github.com/acesseonline/pyreportjasper/blob/master/LICENSE